==> haskell-http-types-0.9.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9.1
id: http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
key: http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
abi: 4cff2812340a9bb4a66388e87fbc9e24
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-types-0.9.1
hs-libraries: HShttp-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
depends:
    array-0.5.1.1 base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-6RHKQz6dPK3ENaPtabAPQ
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.9.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9.1
id: http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
key: http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
abi: f662dee43f3bce1e09fe62b97fd62dd4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/http-types-0.9.1
hs-libraries: HShttp-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
depends:
    array-0.5.1.1 base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
